@@ -6,7 +6,7 @@ var dir_04d2bd150f7cc849eeec70b9b0fdccb1 =
     [ "exif-data.h", "exif-data_8h.html", "exif-data_8h" ],
     [ "exif-entry.h", "exif-entry_8h.html", "exif-entry_8h" ],
     [ "exif-format.h", "exif-format_8h.html", "exif-format_8h" ],
-    [ "exif-gps-ifd.c", "exif-gps-ifd_8c.html", "exif-gps-ifd_8c" ],
+    [ "exif-gps-ifd.c", "exif-gps-ifd_8c.html", null ],
     [ "exif-gps-ifd.h", "exif-gps-ifd_8h.html", "exif-gps-ifd_8h" ],
     [ "exif-ifd.h", "exif-ifd_8h_source.html", null ],
     [ "exif-loader.h", "exif-loader_8h.html", "exif-loader_8h" ],
@@ -14,9 +14,9 @@ var dir_04d2bd150f7cc849eeec70b9b0fdccb1 =
     [ "exif-mem.h", "exif-mem_8h.html", "exif-mem_8h" ],
     [ "exif-mnote-data-priv.h", "exif-mnote-data-priv_8h_source.html", null ],
     [ "exif-mnote-data.h", "exif-mnote-data_8h.html", "exif-mnote-data_8h" ],
-    [ "exif-system.h", "exif-system_8h.html", "exif-system_8h" ],
+    [ "exif-system.h", "exif-system_8h.html", null ],
     [ "exif-tag.h", "exif-tag_8h.html", "exif-tag_8h" ],
     [ "exif-utils.h", "exif-utils_8h.html", "exif-utils_8h" ],
-    [ "exif.h", "exif_8h_source.html", null ],
+    [ "exif.h", "exif_8h.html", null ],
     [ "i18n.h", "i18n_8h_source.html", null ]
 ];
\ No newline at end of file
